@@ -59,6 +59,10 @@ type value; \
 
 std::string read_string(std::istream & stream, unsigned int size)
 {
+    if(size == 0)
+    {
+        return std::string();
+    }
     std::string value(size, '\0');
     stream.read(&value[0], value.size());
     if(!stream)
@@ -89,7 +93,7 @@ DataSet
 Reader
 ::read_data_set(std::function<bool(Tag const &)> halt_condition) const
 {
-    DataSet data_set;
+    DataSet data_set(transfer_syntax);
 
     bool done = (this->stream.peek() == EOF);
     while(!done)
@@ -184,7 +188,9 @@ Reader
 
 std::pair<DataSet, DataSet>
 Reader
-::read_file(std::istream & stream, bool keep_group_length)
+::read_file(
+    std::istream & stream, bool keep_group_length,
+    std::function<bool(Tag const &)> halt_condition)
 {
     // File preamble
     stream.ignore(128);
@@ -222,7 +228,7 @@ Reader
     Reader data_set_reader(
         stream, meta_information.as_string(registry::TransferSyntaxUID)[0],
         keep_group_length);
-    auto const data_set = data_set_reader.read_data_set();
+    auto const data_set = data_set_reader.read_data_set(halt_condition);
 
     return std::pair<DataSet, DataSet>(meta_information, data_set);
 }
@@ -319,7 +325,11 @@ Reader::Visitor
             value.resize(strings.size());
             std::transform(
                 strings.begin(), strings.end(), value.begin(),
-                [](std::string const & s) { return std::stod(s); });
+                [](std::string const & s)
+                {
+                    return static_cast<Value::Real>(std::stold(s));
+                }
+            );
         }
     }
     else
@@ -465,50 +475,57 @@ Reader::Visitor
 ::operator()(Value::Binary & value) const
 {
     auto const vl = this->read_length();
-
-    if(this->vr == VR::OB)
+    if(vl == 0)
     {
-        value.resize(vl);
-        this->stream.read(reinterpret_cast<char*>(&value[0]), value.size());
+        return;
     }
-    else if(this->vr == VR::OF)
+    else if(vl == 0xffffffff)
     {
-        if(vl%4 != 0)
-        {
-            throw Exception("Cannot read OF for odd-sized array");
-        }
-
-        value.resize(vl);
-        for(unsigned int i=0; i<value.size(); i+=4)
-        {
-            odil_read_binary(
-                float, item, this->stream, this->byte_ordering, 32);
-            *reinterpret_cast<float*>(&value[i]) = item;
-        }
-    }
-    else if(this->vr == VR::OW)
-    {
-        if(vl%2 != 0)
-        {
-            throw Exception("Cannot read OW for odd-sized array");
-        }
-
-        value.resize(vl);
-        for(unsigned int i=0; i<value.size(); i+=2)
-        {
-            odil_read_binary(
-                uint16_t, item, this->stream, this->byte_ordering, 16);
-            *reinterpret_cast<uint16_t*>(&value[i]) = item;
-        }
-    }
-    else if(this->vr == VR::UN)
-    {
-        value.resize(vl);
-        this->stream.read(reinterpret_cast<char*>(&value[0]), value.size());
+        value = this->read_encapsulated_pixel_data(this->stream);
     }
     else
     {
-        throw Exception("Cannot read "+as_string(this->vr)+" as binary");
+        value.resize(1);
+        if(this->vr == VR::OB || this->vr == VR::UN)
+        {
+            value[0].resize(vl);
+            this->stream.read(
+                reinterpret_cast<char*>(&value[0][0]), value[0].size());
+        }
+        else if(this->vr == VR::OF)
+        {
+            if(vl%4 != 0)
+            {
+                throw Exception("Cannot read OF for odd-sized array");
+            }
+
+            value[0].resize(vl);
+            for(unsigned int i=0; i<value[0].size(); i+=4)
+            {
+                odil_read_binary(
+                    float, item, this->stream, this->byte_ordering, 32);
+                *reinterpret_cast<float*>(&value[0][i]) = item;
+            }
+        }
+        else if(this->vr == VR::OW)
+        {
+            if(vl%2 != 0)
+            {
+                throw Exception("Cannot read OW for odd-sized array");
+            }
+
+            value[0].resize(vl);
+            for(unsigned int i=0; i<value[0].size(); i+=2)
+            {
+                odil_read_binary(
+                    uint16_t, item, this->stream, this->byte_ordering, 16);
+                *reinterpret_cast<uint16_t*>(&value[0][i]) = item;
+            }
+        }
+        else
+        {
+            throw Exception("Cannot read "+as_string(this->vr)+" as binary");
+        }
     }
 }
 
@@ -605,6 +622,53 @@ Reader::Visitor
     return item;
 }
 
+Value::Binary
+Reader::Visitor
+::read_encapsulated_pixel_data(std::istream & specific_stream) const
+{
+    Value::Binary value;
+
+    // PS 3.5, A.4
+    Reader const sequence_reader(
+        specific_stream, this->transfer_syntax, this->keep_group_length);
+    bool done = false;
+    while(!done)
+    {
+        auto const tag = sequence_reader.read_tag();
+        odil_read_binary(
+            uint32_t, item_length, specific_stream, this->byte_ordering, 32);
+
+        if(tag == registry::Item)
+        {
+            Value::Binary::value_type item_data(item_length);
+
+            if(item_length > 0)
+            {
+                specific_stream.read(
+                    reinterpret_cast<char*>(&item_data[0]), item_length);
+                if(!stream)
+                {
+                    throw Exception("Could not read from stream");
+                }
+            }
+
+            value.push_back(item_data);
+        }
+        else if(tag == registry::SequenceDelimitationItem)
+        {
+            // No value for Sequence Delimitation Item
+            done = true;
+        }
+        else
+        {
+            throw Exception(
+                "Expected SequenceDelimitationItem, got: "+std::string(tag));
+        }
+    }
+
+    return value;
+}
+
 }
 
 #undef odil_ignore
