@@ -67,9 +67,11 @@ public:
         Tag const & tag=Tag(0xffff,0xffff),
         DataSet const & data_set=DataSet()) const;
 
+    /// @brief Return the meta-data header and data set stored in the stream.
     static std::pair<DataSet, DataSet> read_file(
         std::istream & stream,
-        bool keep_group_length=false);
+        bool keep_group_length=false,
+        std::function<bool(Tag const &)> halt_condition = [](Tag const &) { return false;});
 
 private:
     struct Visitor
@@ -98,6 +100,8 @@ private:
 
         Value::Strings split_strings(std::string const & string) const;
         DataSet read_item(std::istream & specific_stream) const;
+        Value::Binary read_encapsulated_pixel_data(
+            std::istream & specific_stream) const;
     };
 };
 
