@@ -17,6 +17,7 @@
 namespace odil
 {
 
+/// @brief Element visitor converting to XML.
 struct ToXMLVisitor
 {
     typedef boost::property_tree::ptree result_type;
@@ -208,6 +209,15 @@ struct ToXMLVisitor
 
     result_type operator()(VR const vr, Value::Binary const & value) const
     {
+        if(value.size() > 1)
+        {
+            // PS3.18 2016b, F.2.7: There is a single InlineBinary value
+            // representing the entire Value Field.
+            // PS3.18 2016b, Figure 6.5-1: Pixel data is not encoded in
+            // JSON/XML, but transfered using a different content type
+            throw Exception("Binary element is multiple-valued");
+        }
+
         result_type result;
 
         result.put("<xmlattr>.vr", as_string(vr)); // Mandatory
@@ -215,8 +225,8 @@ struct ToXMLVisitor
         boost::property_tree::ptree tag_value;
 
         std::string encoded;
-        encoded.reserve(value.size()*4/3);
-        base64::encode(value.begin(), value.end(), std::back_inserter(encoded));
+        encoded.reserve(value[0].size()*4/3);
+        base64::encode(value[0].begin(), value[0].end(), std::back_inserter(encoded));
         tag_value.put_value(encoded);
 
         result.add_child("InlineBinary", tag_value);
@@ -328,16 +338,15 @@ boost::property_tree::ptree as_xml(DataSet const & data_set)
         boost::property_tree::ptree dicomattribute =
                 apply_visitor(ToXMLVisitor(), element);
 
-        auto const dictionary_it = registry::public_dictionary.find(tag);
-        if(dictionary_it == registry::public_dictionary.end())
-        {
-            throw Exception("No such element: " + std::string(tag));
-        }
-
         // Add Mandatory attribute Tag
         dicomattribute.put("<xmlattr>.tag",  std::string(tag));
         // Add Optional attribute Keyword
-        dicomattribute.put("<xmlattr>.keyword", dictionary_it->second.keyword);
+        auto const dictionary_it = registry::public_dictionary.find(tag);
+        if(dictionary_it != registry::public_dictionary.end())
+        {
+            dicomattribute.put(
+                "<xmlattr>.keyword", dictionary_it->second.keyword);
+        }
         // Add Optional attribute PrivateCreator
         //dicomattribute.put("<xmlattr>.privateCreator", todo);
 
@@ -566,11 +575,14 @@ DataSet as_dataset(boost::property_tree::ptree const & xml)
                 }
 
                 auto const & encoded = it_value->second.get_value<std::string>();
+                // cf. ToXMLVisitor::operator()(VR, Value::Binary): InlineBinary
+                // is single-valued
                 auto & decoded = element.as_binary();
-                decoded.reserve(encoded.size()*3/4);
+                decoded.resize(1);
+                decoded[0].reserve(encoded.size()*3/4);
                 base64::decode(
                     encoded.begin(), encoded.end(),
-                    std::back_inserter(decoded));
+                    std::back_inserter(decoded[0]));
 
                 find_inline_binary = true;
             }
